@@ -29,6 +29,6 @@ class PracticeService:
 
     def is_practice_active(self, practice_id: uuid.UUID) -> bool:
         request_path = f"/practices/{str(practice_id)}/is_active"
-        response_code = self.service_provider.fetch_data(
-            request_path).code
+        response_code = self.service_provider.fetch_data(request_path).code
+
         return response_code == status.HTTP_200_OK
